@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2009-2022, Peter Haag
+ *  Copyright (c) 2009-2023, Peter Haag
  *  Copyright (c) 2004-2008, SWITCH - Teleinformatikdienste fuer Lehre und Forschung
  *  All rights reserved.
  *
@@ -211,7 +211,9 @@ static queue_t *file_queue = NULL;
 
 /* Function prototypes */
 
-static void GetFileList(char *path);
+static int CreateDirListFilter(char *first_path, char *last_path, int file_list_level);
+
+static int GetFileList(char *path, timeWindow_t *timeWindow);
 
 static void CleanPath(char *entry);
 
@@ -219,8 +221,12 @@ static void Getsource_dirs(char *dirs);
 
 static int mkpath(char *path, char *p, mode_t mode, mode_t dir_mode, char *error, size_t errlen);
 
+static char *SubDirList(char *path);
+
 static char *GuessSubDir(char *channeldir, char *filename);
 
+static char *ExpandWildcard(char *path);
+
 static char *VerifyFileRange(char *path, char *last_file);
 
 static void *FileLister_thr(void *arg);
@@ -281,24 +287,24 @@ static int dirlevels(char *dir) {
 
 }  // End of dirlevels
 
-static void CreateDirListFilter(char *first_path, char *last_path, int file_list_level) {
+static int CreateDirListFilter(char *first_path, char *last_path, int file_list_level) {
     int i;
     char *p, *q, *first_mark, *last_mark;
 
-    //	printf("First Dir: '%s', first_path: '%s', last_path '%s', first_file '%s', last_file '%s', list_level: %i\n",
-    //			source_dirs.list[0], first_path, last_path, first_file, last_file, file_list_level);
+    dbg_printf("CreateDirListFilter() First Dir: '%s', first_path: '%s', last_path '%s', first_file '%s', last_file '%s', list_level: %i\n",
+               source_dirs.list[0], first_path, last_path, first_file, last_file, file_list_level);
 
-    if (file_list_level == 0) return;
+    if (file_list_level == 0) return 1;
 
     if (file_list_level < 0) {
         LogError("software error in %s line %d: %s", __FILE__, __LINE__, strerror(errno));
-        exit(250);
+        return 0;
     }
 
     dir_entry_filter = (struct entry_filter_s *)malloc((file_list_level + 1) * sizeof(struct entry_filter_s));
     if (!dir_entry_filter) {
         LogError("malloc() error in %s line %d: %s", __FILE__, __LINE__, strerror(errno));
-        exit(250);
+        return 0;
     }
 
     // first default entry - the directory itself
@@ -344,8 +350,7 @@ static void CreateDirListFilter(char *first_path, char *last_path, int file_list
             strcmp(dir_entry_filter[i].first_entry, dir_entry_filter[i].last_entry) > 0)
             LogError("WARNING: Entry '%s' > '%s'. Will not match anything!", dir_entry_filter[i].first_entry, dir_entry_filter[i].last_entry);
 
-        //		printf("%i first: '%s', last: '%s'\n",
-        //			i, dir_entry_filter[i].first_entry, dir_entry_filter[i].last_entry);
+        dbg_printf("%i first: '%s', last: '%s'\n", i, dir_entry_filter[i].first_entry, dir_entry_filter[i].last_entry);
     }
 
     // the last level - files are listed here
@@ -358,12 +363,87 @@ static void CreateDirListFilter(char *first_path, char *last_path, int file_list
         LogError("WARNING: File '%s' > '%s'. Will not match anything!", dir_entry_filter[file_list_level].first_entry,
                  dir_entry_filter[file_list_level].last_entry);
 
-    //	printf("%i first: '%s', last: '%s'\n",
-    //		file_list_level, dir_entry_filter[file_list_level].first_entry, dir_entry_filter[file_list_level].last_entry);
+    dbg_printf("%i first: '%s', last: '%s'\n", file_list_level, dir_entry_filter[file_list_level].first_entry,
+               dir_entry_filter[file_list_level].last_entry);
+
+    return 1;
 
 }  // End of CreateDirListFilter
 
-static void GetFileList(char *path) {
+static char *SubDirList(char *path) {
+    char *dirList = NULL;
+    struct dirent *dent;
+    DIR *srcdir = opendir(path);
+
+    if (srcdir == NULL) {
+        LogError("opendir() - can not open directory %s", path);
+        return NULL;
+    }
+
+    while ((dent = readdir(srcdir)) != NULL) {
+        struct stat st;
+        if (strcmp(dent->d_name, ".") == 0 || strcmp(dent->d_name, "..") == 0) continue;
+
+        if (fstatat(dirfd(srcdir), dent->d_name, &st, 0) < 0) {
+            LogError("fstatat() - can not stat %s", dent->d_name);
+            continue;
+        }
+
+        if (S_ISDIR(st.st_mode)) {
+            if (dirList == NULL) {
+                dirList = strdup(dent->d_name);
+            } else {
+                size_t len = strlen(dirList) + strlen(dent->d_name) + 2;
+                dirList = realloc(dirList, len);
+                if (dirList == NULL) {
+                    LogError("realloc() error in %s line %d: %s", __FILE__, __LINE__, strerror(errno));
+                    return NULL;
+                }
+                strcat(dirList, ":");
+                strcat(dirList, dent->d_name);
+            }
+        }
+    }
+    closedir(srcdir);
+    return dirList;
+}  // Endof SubDirList
+
+/*
+ * Check for directory wildcard:
+ * path: /any/path/dir@
+ * if wildcard is found - extend to directory list:
+ * /any/path/dir/dir1:dir2:dir3:dirN
+ * returns expanded directory string or NULL if no wildcard found
+ */
+static char *ExpandWildcard(char *path) {
+    char *q = strchr(path, ':');
+    size_t dirLen = strlen(path);
+    int wildcard = path[dirLen - 1] == '@';
+
+    if (q && wildcard) {
+        LogError("Can not process wildcard '@' and dirlist ':' in %s", path);
+        LogError("Remove wildcard");
+        path[dirLen - 1] = '\0';
+        return NULL;
+    }
+    if (wildcard == 0) return NULL;
+
+    // remove '@' and replace it by '/'
+    path[dirLen - 1] = '/';
+    char *dirList = SubDirList(path);
+    if (dirList == NULL) {
+        LogError("Can not expand wildcard in %s", path);
+        return NULL;
+    }
+    path = realloc(path, strlen(path) + strlen(dirList) + 1);
+    if (path == NULL) {
+        LogError("realloc() error in %s line %d: %s", __FILE__, __LINE__, strerror(errno));
+        return NULL;
+    }
+    return strcat(path, dirList);
+}  // End of ExpandWildcard
+
+static int GetFileList(char *path, timeWindow_t *timeWindow) {
     struct stat stat_buf;
     char *last_file_ptr, *first_path, *last_path;
     int levels_first_file, levels_last_file, file_list_level;
@@ -382,21 +462,21 @@ static void GetFileList(char *path) {
         // make sure we have only a single ':' in path
         if (strrchr(path, ':') != last_file_ptr) {
             LogError("Multiple file separators ':' in path not allowed!");
-            exit(250);
+            return 0;
         }
         *last_file_ptr++ = '\0';
         // last_file_ptr points to last_file
 
         if (strlen(last_file_ptr) == 0) {
             LogError("Missing last file option after ':'!");
-            exit(250);
+            return 0;
         }
 
         CleanPath(last_file_ptr);
         // make sure last_file option is not a full path
         if (last_file_ptr[0] == '/') {
             LogError("Last file name in -R list must not start with '/'");
-            exit(250);
+            return 0;
         }
         // how may sub dir levels has last_file option?
         levels_last_file = dirlevels(last_file_ptr);
@@ -425,11 +505,11 @@ static void GetFileList(char *path) {
         // stat this entry
         if (stat(path, &stat_buf)) {
             LogError("stat() error '%s': %s", path, strerror(errno));
-            exit(250);
+            return 0;
         }
         if (!S_ISDIR(stat_buf.st_mode) && !S_ISREG(stat_buf.st_mode)) {
             LogError("Not a file or directory: '%s'", path);
-            exit(250);
+            return 0;
         }
 
         // Check, how many levels of directory in path
@@ -441,7 +521,7 @@ static void GetFileList(char *path) {
             // make sure first_file is a file
             if (S_ISDIR(stat_buf.st_mode)) {
                 LogError("Not a file: '%s'", path);
-                exit(250);
+                return 0;
             }
 
             if (levels_last_file) {
@@ -450,7 +530,7 @@ static void GetFileList(char *path) {
                 // sub dir levels of first_file mus have at least the same number of levels as last_file
                 if (levels_first_file < levels_last_file) {
                     LogError("Number of sub dirs for sub level hierarchy for file list -R do not match");
-                    exit(250);
+                    return 0;
                 }
                 if (levels_first_file == levels_last_file) {
                     char *p, *q;
@@ -469,7 +549,7 @@ static void GetFileList(char *path) {
                     if (!p || !q) {
                         // this should never happen
                         LogError("software error in %s line %d: %s", __FILE__, __LINE__, strerror(errno));
-                        exit(250);
+                        return 0;
                     }
                     *p++ = '\0';
                     *q++ = '\0';
@@ -502,7 +582,7 @@ static void GetFileList(char *path) {
                     if (!r || !s) {
                         // this must never happen
                         LogError("software error in %s line %d: %s", __FILE__, __LINE__, strerror(errno));
-                        exit(250);
+                        return 0;
                     }
                     *r++ = '\0';
                     *s++ = '\0';
@@ -570,7 +650,7 @@ static void GetFileList(char *path) {
         // multiple sources option -M given
         if (path[0] == '/') {
             LogError("File list -R must not start with '/' when combined with a source list -M");
-            exit(250);
+            return 0;
         }
 
         // special case for all files in directory
@@ -609,7 +689,7 @@ static void GetFileList(char *path) {
                                 levels_last_file = dirlevels(last_file_ptr);
                             } else {
                                 LogError("'%s': %s", last_file_ptr, "File not found!");
-                                exit(250);
+                                return 0;
                             }
                         }
 
@@ -619,11 +699,11 @@ static void GetFileList(char *path) {
                     }
                 } else {  // Any other stat error
                     LogError("stat() error '%s': %s", pathbuff, strerror(errno));
-                    exit(250);
+                    return 0;
                 }
             } else if (!S_ISREG(stat_buf.st_mode)) {
                 LogError("Not a file : '%s'", pathbuff);
-                exit(250);
+                return 0;
             }
 
             // Check, how many levels of directory in path
@@ -636,7 +716,7 @@ static void GetFileList(char *path) {
                 // the number of sub dirs must be eqal for first_file and last_file
                 if (levels_first_file != levels_last_file) {
                     LogError("Number of sub dirs must agree in '%s' and '%s'", path, last_file_ptr);
-                    exit(250);
+                    return 0;
                 }
 
                 p = strrchr(path, '/');
@@ -682,10 +762,16 @@ static void GetFileList(char *path) {
         }
     }
 
-    CreateDirListFilter(first_path, last_path, file_list_level);
+    if (!CreateDirListFilter(first_path, last_path, file_list_level)) {
+        return 0;
+    }
 
     // last entry must be NULL
     InsertString(&source_dirs, NULL);
+    if (!source_dirs.list) {
+        LogError("ERROR: No sourc dir at %s line %d", __FILE__, __LINE__);
+        return 0;
+    }
     fts = fts_open(source_dirs.list, FTS_LOGICAL, compare);
     sub_index = 0;
     while ((ftsent = fts_read(fts)) != NULL) {
@@ -699,12 +785,12 @@ static void GetFileList(char *path) {
 
         if (dir_entry_filter && (fts_level > file_list_level)) {
             LogError("ERROR: fts_level error at %s line %d", __FILE__, __LINE__);
-            exit(250);
+            return 0;
         }
 
         if (ftsent->fts_pathlen < sub_index) {
             LogError("ERROR: fts_pathlen error at %s line %d", __FILE__, __LINE__);
-            exit(250);
+            return 0;
         }
         fts_path = &ftsent->fts_path[sub_index];
 
@@ -736,12 +822,15 @@ static void GetFileList(char *path) {
                      (dir_entry_filter[fts_level].last_entry && (strcmp(ftsent->fts_name, dir_entry_filter[fts_level].last_entry) > 0))))
                     continue;
 
-                queue_push(file_queue, strdup(ftsent->fts_path));
+                if (CheckTimeWindow(ftsent->fts_path, timeWindow)) {
+                    queue_push(file_queue, strdup(ftsent->fts_path));
+                }
                 break;
         }
     }
     fts_close(fts);
 
+    return 1;
 }  // End of GetFileList
 
 /*
@@ -845,11 +934,20 @@ static void *FileLister_thr(void *arg) {
     last_file = NULL;
 
     InitStringlist(&source_dirs, NUM_PTR);
-    if (flist->multiple_dirs) Getsource_dirs(flist->multiple_dirs);
+    if (flist->multiple_dirs) {
+        char *expanded = ExpandWildcard(flist->multiple_dirs);
+        if (expanded) {
+            flist->multiple_dirs = expanded;
+        }
+        Getsource_dirs(flist->multiple_dirs);
+    }
 
     if (flist->multiple_files) {
         // use multiple files
-        GetFileList(flist->multiple_files);
+        if (!GetFileList(flist->multiple_files, flist->timeWindow)) {
+            queue_close(file_queue);
+            pthread_exit(NULL);
+        }
     } else if (single_file) {
         CleanPath(single_file);
 
@@ -864,13 +962,15 @@ static void *FileLister_thr(void *arg) {
 
             if (single_file[0] == '/') {
                 LogError("File -r must not start with '/', when combined with a source list -M");
-                exit(250);
+                queue_close(file_queue);
+                pthread_exit(NULL);
             }
 
             for (i = 0; i < source_dirs.num_strings; i++) {
                 char s[MAXPATHLEN];
                 struct stat stat_buf;
 
+                dbg_printf("Src dir: %d, %s\n", i, source_dirs.list[i]);
                 snprintf(s, MAXPATHLEN - 1, "%s/%s", source_dirs.list[i], single_file);
                 s[MAXPATHLEN - 1] = '\0';
                 if (stat(s, &stat_buf)) {
@@ -888,7 +988,8 @@ static void *FileLister_thr(void *arg) {
                         }
                     } else {  // Any other stat error
                         LogError("stat() error '%s': %s", s, strerror(errno));
-                        exit(250);
+                        queue_close(file_queue);
+                        pthread_exit(NULL);
                     }
                 } else {  // stat() successful
                     if (!S_ISREG(stat_buf.st_mode)) {
