@@ -71,6 +71,12 @@ typedef struct recordHeaderV3_s {
 } recordHeaderV3_t;
 #define OFFtype offsetof(recordHeaderV3_t, type)
 #define SIZEtype MemberSize(recordHeaderV3_t, type)
+#define OFFengineType offsetof(recordHeaderV3_t, engineType)
+#define SIZEengineType MemberSize(recordHeaderV3_t, engineType)
+#define OFFengineID offsetof(recordHeaderV3_t, engineID)
+#define SIZEengineID MemberSize(recordHeaderV3_t, engineID)
+#define OFFexporterID offsetof(recordHeaderV3_t, exporterID)
+#define SIZEexporterID MemberSize(recordHeaderV3_t, exporterID)
 
 #define V3HeaderRecordSize sizeof(recordHeaderV3_t)
 #define AddV3Header(p, h)                        \
@@ -227,9 +233,10 @@ typedef struct EXflowMisc_s {
     uint8_t flowEndReason;
 #define OFFflowEndReason offsetof(EXflowMisc_t, flowEndReason)
 #define SIZEflowEndReason MemberSize(EXflowMisc_t, flowEndReason)
-    // align bytes
     uint8_t revTcpFlags;
-    uint8_t fill;
+    uint8_t fragmentFlags;
+#define OFFfragmentFlags offsetof(EXflowMisc_t, fragmentFlags)
+#define SIZEfragmentFlags MemberSize(EXflowMisc_t, fragmentFlags)
 } EXflowMisc_t;
 #define EXflowMiscSize (sizeof(EXflowMisc_t) + sizeof(elementHeader_t))
 
@@ -527,7 +534,7 @@ typedef struct EXnbarApp_s {
 #define EXlabelID 28
 #define EXlabelSize sizeof(elementHeader_t)
 
-#define EXinPayload_t elementHeader_t
+#define EXinPayload_t void
 #define EXinPayloadID 29
 #define EXinPayloadSize sizeof(elementHeader_t)
 
@@ -543,8 +550,8 @@ typedef struct EXtunIPv4_s {
 #define SIZEtunSrc4Addr MemberSize(EXtunIPv4_t, tunSrcAddr)
 #define OFFtunDst4Addr offsetof(EXtunIPv4_t, tunDstAddr)
 #define SIZEtunDst4Addr MemberSize(EXtunIPv4_t, tunDstAddr)
-#define OFFtunProto offsetof(EXtunIPv4_t, tunProto)
-#define SIZEtunProto MemberSize(EXtunIPv4_t, tunProto)
+#define OFFtunProtoV4 offsetof(EXtunIPv4_t, tunProto)
+#define SIZEtunProtoV4 MemberSize(EXtunIPv4_t, tunProto)
 } EXtunIPv4_t;
 #define EXtunIPv4Size (sizeof(EXtunIPv4_t) + sizeof(elementHeader_t))
 
@@ -557,6 +564,8 @@ typedef struct EXtunIPv6_s {
 #define SIZEtunSrc6Addr MemberSize(EXtunIPv6_t, tunSrcAddr)
 #define OFFtunDst6Addr offsetof(EXtunIPv6_t, tunDstAddr)
 #define SIZEtunDst6Addr MemberSize(EXtunIPv6_t, tunDstAddr)
+#define OFFtunProtoV6 offsetof(EXtunIPv6_t, tunProto)
+#define SIZEtunProtoV6 MemberSize(EXtunIPv6_t, tunProto)
 } EXtunIPv6_t;
 #define EXtunIPv6Size (sizeof(EXtunIPv6_t) + sizeof(elementHeader_t))
 
@@ -613,6 +622,16 @@ typedef struct EXpfinfo_s {
     uint32_t pid;
     char ifname[4];
 } EXpfinfo_t;
+#define OFFpfAction offsetof(EXpfinfo_t, action)
+#define SIZEpfAction MemberSize(EXpfinfo_t, action)
+#define OFFpfReason offsetof(EXpfinfo_t, reason)
+#define SIZEpfReason MemberSize(EXpfinfo_t, reason)
+#define OFFpfDir offsetof(EXpfinfo_t, dir)
+#define SIZEpfDir MemberSize(EXpfinfo_t, dir)
+#define OFFpfIfName offsetof(EXpfinfo_t, ifname)
+#define SIZEpfIfName MemberSize(EXpfinfo_t, ifname)
+#define OFFpfRuleNr offsetof(EXpfinfo_t, rulenr)
+#define SIZEpfRuleNr MemberSize(EXpfinfo_t, rulenr)
 #define EXpfinfoSize (sizeof(EXpfinfo_t) - 4 + sizeof(elementHeader_t))
 
 // max possible elements
