@@ -29,14 +29,12 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #ifndef SYSLOG_NAMES
 #define SYSLOG_NAMES 1
 #endif
 
+#include "util.h"
+
 #include <arpa/inet.h>
 #include <errno.h>
 #include <limits.h>
@@ -55,8 +53,6 @@
 #include <time.h>
 #include <unistd.h>
 
-#include "util.h"
-
 /* Global vars */
 
 static int verbose = 4;
