@@ -293,6 +293,8 @@ typedef struct ipfix_template_elements_e_s {
 #define IPFIX_icmpTypeV6 178
 #define IPFIX_icmpCodeV6 179
 
+#define IPFIX_fragmentFlags 197
+
 #define IPFIX_postNATSourceIPv4Address 225
 #define IPFIX_postNATDestinationIPv4Address 226
 #define IPFIX_postNAPTSourceTransportPort 227
@@ -319,6 +321,13 @@ typedef struct ipfix_template_elements_e_s {
 #define IPFIX_samplingPacketInterval 305
 #define IPFIX_samplingPacketSpace 306
 
+// cgNAT
+#define IPFIX_NATPOOL_ID 283
+#define IPFIX_PORT_BLOCK_START 361
+#define IPFIX_PORT_BLOCK_END 362
+#define IPFIX_PORT_BLOCK_STEP 363
+#define IPFIX_PORT_BLOCK_SIZE 364
+
 // Juniper inline-monitoring
 #define IPFIX_dataLinkFrameSize 312
 #define IPFIX_dataLinkFrameSection 315
