@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2009-2020, Peter Haag
+ *  Copyright (c) 2009-2023, Peter Haag
  *  Copyright (c) 2004-2008, SWITCH - Teleinformatikdienste fuer Lehre und Forschung
  *  All rights reserved.
  *
@@ -346,6 +346,7 @@ static inline record_header_t *ConvertRecordV2(common_record_t *input_record) {
             case EX_NSEL_USER_MAX: {
                 tpl_ext_43_t *tpl = (tpl_ext_43_t *)p;
                 PushExtension(recordHeader, EXnselUser, nselUser);
+                tpl->username[65] = '\0';  // truncate old username
                 strncpy((void *)nselUser->username, (void *)tpl->username, 65);
                 nselUser->username[65] = '\0';
                 p = (void *)tpl->data;
@@ -353,8 +354,8 @@ static inline record_header_t *ConvertRecordV2(common_record_t *input_record) {
             case EX_NSEL_USER: {
                 tpl_ext_42_t *tpl = (tpl_ext_42_t *)p;
                 PushExtension(recordHeader, EXnselUser, nselUser);
-                strncpy((void *)nselUser->username, (void *)tpl->username, 24);
-                nselUser->username[25] = '\0';
+                strncpy((void *)nselUser->username, (void *)tpl->username, 65);
+                nselUser->username[65] = '\0';
                 p = (void *)tpl->data;
             } break;
             case EX_NEL_COMMON: {
@@ -493,9 +494,6 @@ static inline int ExpandRecord_v2(record_header_t *record_ptr, master_record_t *
     }
     output_record->label = NULL;
 
-    // map icmp type/code in it's own vars
-    output_record->icmp = output_record->dstPort;
-
     // Required extension 1 - IP addresses
     if (TestFlag(input_record->flags, FLAG_IPV6_ADDR)) {  // IPv6
         // IPv6
@@ -847,7 +845,8 @@ static inline int ExpandRecord_v2(record_header_t *record_ptr, master_record_t *
                 output_record->event = tpl->fw_event;
                 output_record->event_flag = FW_EVENT;
                 output_record->fwXevent = tpl->fw_xevent;
-                output_record->icmp = tpl->nsel_icmp;
+                if ((output_record->proto == IPPROTO_ICMP || output_record->proto == IPPROTO_ICMPV6) && output_record->dstPort == 0)
+                    output_record->dstPort = tpl->nsel_icmp;
                 output_record->sec_group_tag = tpl->sec_group_tag;
                 p = (void *)tpl->data;
             } break;
