@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2009-2023, Peter Haag
+ *  Copyright (c) 2009-2024, Peter Haag
  *  Copyright (c) 2004-2008, SWITCH - Teleinformatikdienste fuer Lehre und Forschung
  *  All rights reserved.
  *
@@ -91,6 +91,7 @@ static void usage(char *name) {
         "-z=lzo\t\tLZO compress flows in output file.\n"
         "-z=bz2\t\tBZIP2 compress flows in output file.\n"
         "-z=lz4[:level]\tLZ4 compress flows in output file.\n"
+        "-z=zstd[:level]\tZSTD compress flows in output file.\n"
 #ifdef HAVE_INFLUXDB
         "-i <influxurl>\tInfluxdb url for stats (example: http://localhost:8086/write?db=mydb&u=pippo&p=paperino)\n"
 #endif
@@ -228,6 +229,15 @@ static void process_data(profile_channel_info_t *channels, unsigned int num_chan
                     }
                 } break;
                 case NbarRecordType:
+                case IfNameRecordType:
+                case VrfNameRecordType:
+                    for (int j = 0; j < num_channels; j++) {
+                        if (channels[j].nffile != NULL) {
+                            // flush new map
+                            AppendToBuffer(channels[j].nffile, (void *)record_ptr, record_ptr->size);
+                        }
+                    }
+                    break;
                 case LegacyRecordType1:
                 case LegacyRecordType2:
                 case ExporterStatRecordType:
@@ -524,7 +534,7 @@ int main(int argc, char **argv) {
                 break;
             case 'z':
                 if (compress) {
-                    LogError("Use one compression: -z for LZO, -j for BZ2 or -y for LZ4 compression");
+                    LogError("Use one compression only: set -z=lzo, -z=lz4, -z=bz2 or z=zstd for valid compression formats");
                     exit(EXIT_FAILURE);
                 }
                 if (optarg == NULL) {
@@ -533,7 +543,7 @@ int main(int argc, char **argv) {
                     compress = ParseCompression(optarg);
                 }
                 if (compress == -1) {
-                    LogError("Usage for option -z: set -z=lzo, -z=lz4 or -z=bz2 for valid compression formats");
+                    LogError("Usage for option -z: set -z=lzo, -z=lz4, -z=bz2 or z=zstd for valid compression formats");
                     exit(EXIT_FAILURE);
                 }
                 break;
