@@ -53,6 +53,7 @@
 #include "nffile.h"
 #include "nfxV3.h"
 #include "output_util.h"
+#include "userio.h"
 #include "util.h"
 
 typedef void (*string_function_t)(FILE *, master_record_t *);
@@ -342,13 +343,13 @@ static struct format_token_list_s {
                          {"%cnt", 0, "Count", String_FlowCount},                             // flow count
                          {"%tfs", 0, "Date first seen        ", String_FirstSeen},           // Start Time - first seen
                          {"%ts", 0, "Date first seen        ", String_FirstSeen},            // Start Time - first seen
-                         {"%tsr", 0, "Date first seen (raw)    ", String_FirstSeenRaw},      // Start Time - first seen, seconds
+                         {"%tsr", 0, "First seen raw", String_FirstSeenRaw},                 // Start Time - first seen, seconds
                          {"%te", 0, "Date last seen         ", String_LastSeen},             // End Time	- last seen
-                         {"%ter", 0, "Date last seen (raw)     ", String_LastSeenRaw},       // End Time - first seen, seconds
+                         {"%ter", 0, "Last seen raw ", String_LastSeenRaw},                  // End Time - first seen, seconds
                          {"%tr", 0, "Date flow received     ", String_Received},             // Received Time
-                         {"%trr", 0, "Date flow received (raw)  ", String_ReceivedRaw},      // Received Time, seconds
-                         {"%td", 0, "    Duration    ", String_Duration},                    // Duration
-                         {"%tds", 0, "    Duration    ", String_Duration_Seconds},           // Duration always in seconds
+                         {"%trr", 0, "Received raw  ", String_ReceivedRaw},                  // Received Time, seconds
+                         {"%td", 0, "Duration        ", String_Duration},                    // Duration
+                         {"%tds", 0, "Duration        ", String_Duration_Seconds},           // Duration always in seconds
                          {"%exp", 0, "Exp ID", String_ExpSysID},                             // Exporter SysID
                          {"%pr", 0, "Proto", String_Protocol},                               // Protocol
                          {"%sa", 1, "     Src IP Addr", String_SrcAddr},                     // Source Address
@@ -384,7 +385,7 @@ static struct format_token_list_s {
                          {"%obyt", 0, "Out Byte", String_OutBytes},                          // In Bytes
                          {"%fl", 0, "Flows", String_Flows},                                  // Flows
                          {"%flg", 0, "   Flags", String_Flags},                              // TCP Flags
-                         {"%tos", 0, "Tos", String_Tos},                                     // Tos - compat
+                         {"%tos", 0, "Tos ", String_Tos},                                    // Tos - compat
                          {"%stos", 0, "STos", String_SrcTos},                                // Tos - Src tos
                          {"%dtos", 0, "DTos", String_DstTos},                                // Tos - Dst tos
                          {"%dir", 0, "Dir", String_Dir},                                     // Direction: ingress, egress
@@ -450,7 +451,7 @@ static struct format_token_list_s {
                          // NSEL specifics
                          {"%nfc", 0, "   Conn-ID", String_nfc},                            // NSEL connection ID
                          {"%tevt", 0, "Event time             ", String_EventTime},        // NSEL Flow start time
-                         {"%evt", 0, " Event", String_evt},                                // NSEL event
+                         {"%evt", 0, "   Event", String_evt},                              // NSEL event
                          {"%xevt", 0, " XEvent", String_xevt},                             // NSEL xevent
                          {"%sgt", 0, "  SGT  ", String_sgt},                               // NSEL xevent
                          {"%msec", 0, "   Event Time", String_msecEvent},                  // NSEL event time in msec
@@ -466,7 +467,7 @@ static struct format_token_list_s {
 
                          // NEL
                          // for v.1.6.10 compatibility, keep NEL specific addr/port format tokens
-                         {"%nevt", 0, " Event", String_evt},                               // NAT event
+                         {"%nevt", 0, "   Event", String_evt},                             // NAT event
                          {"%nsa", 0, "   X-late Src IP", String_xlateSrcAddr},             // NAT XLATE src IP
                          {"%nda", 0, "   X-late Dst IP", String_xlateDstAddr},             // NAT XLATE dst IP
                          {"%nsp", 0, "XsPort", String_xlateSrcPort},                       // NAT XLATE src port
@@ -563,6 +564,25 @@ static void InitFormatParser(void) {
 
 }  // End of InitFormatParser
 
+void CondenseV6(char *s) {
+    size_t len = strlen(s);
+    char *p, *q;
+
+    if (len <= 16) return;
+
+    // orig:      2001:620:1000:cafe:20e:35ff:fec0:fed5 len = 37
+    // condensed: 2001:62..e0:fed5
+    p = s + 7;
+    *p++ = '.';
+    *p++ = '.';
+    q = s + len - 7;
+    while (*q) {
+        *p++ = *q++;
+    }
+    *p = 0;
+
+}  // End of CondenseV6
+
 static void AddToken(int index, char *s) {
     if (token_index >= max_token_index) {  // no slot available - expand table
         max_token_index += BLOCK_SIZE;
@@ -749,11 +769,15 @@ static void String_FirstSeen(FILE *stream, master_record_t *r) {
     struct tm *ts;
     char s[128];
 
-    tt = r->msecFirst / 1000LL;
-    ts = localtime(&tt);
-    strftime(s, 128, "%Y-%m-%d %H:%M:%S", ts);
-    s[127] = '\0';
-    fprintf(stream, "%s.%03u", s, (unsigned)(r->msecFirst % 1000LL));
+    if (r->msecFirst) {
+        tt = r->msecFirst / 1000LL;
+        ts = localtime(&tt);
+        strftime(s, 128, "%Y-%m-%d %H:%M:%S", ts);
+        s[127] = '\0';
+        fprintf(stream, "%s.%03u", s, (unsigned)(r->msecFirst % 1000LL));
+    } else {
+        fprintf(stream, "%s", "0000-00-00 00:00:00.000");
+    }
 
 }  // End of String_FirstSeen
 
@@ -762,11 +786,15 @@ static void String_LastSeen(FILE *stream, master_record_t *r) {
     struct tm *ts;
     char s[128];
 
-    tt = r->msecLast / 1000LL;
-    ts = localtime(&tt);
-    strftime(s, 128, "%Y-%m-%d %H:%M:%S", ts);
-    s[127] = '\0';
-    fprintf(stream, "%s.%03u", s, (unsigned)(r->msecLast % 1000LL));
+    if (r->msecLast) {
+        tt = r->msecLast / 1000LL;
+        ts = localtime(&tt);
+        strftime(s, 128, "%Y-%m-%d %H:%M:%S", ts);
+        s[127] = '\0';
+        fprintf(stream, "%s.%03u", s, (unsigned)(r->msecLast % 1000LL));
+    } else {
+        fprintf(stream, "%s", "0000-00-00 00:00:00.000");
+    }
 
 }  // End of String_LastSeen
 
@@ -775,29 +803,30 @@ static void String_Received(FILE *stream, master_record_t *r) {
     struct tm *ts;
     char s[128];
 
-    tt = r->msecReceived / 1000LL;
-    ts = localtime(&tt);
-    strftime(s, 128, "%Y-%m-%d %H:%M:%S", ts);
-    s[127] = '\0';
-    fprintf(stream, "%s.%03llu", s, r->msecReceived % 1000LL);
+    if (r->msecReceived) {
+        tt = r->msecReceived / 1000LL;
+        ts = localtime(&tt);
+        strftime(s, 128, "%Y-%m-%d %H:%M:%S", ts);
+        s[127] = '\0';
+        fprintf(stream, "%s.%03llu", s, r->msecReceived % 1000LL);
+    } else {
+        fprintf(stream, "%s", "0000-00-00 00:00:00.000");
+    }
 
 }  // End of String_Received
 
 static void String_ReceivedRaw(FILE *stream, master_record_t *r) {
-    /* snprintf does write \0, and the max is INCL the terminating \0 */
-    fprintf(stream, "%.3f", r->msecReceived / 1000.0);
+    fprintf(stream, "%10llu.%03llu", r->msecReceived / 1000LL, r->msecReceived % 1000LL);
 
 }  // End of String_ReceivedRaw
 
 static void String_FirstSeenRaw(FILE *stream, master_record_t *r) {
-    /* snprintf does write \0, and the max is INCL the terminating \0 */
-    fprintf(stream, "%llu.%03llu", r->msecFirst / 1000LL, r->msecFirst % 1000LL);
+    fprintf(stream, "%10llu.%03llu", r->msecFirst / 1000LL, r->msecFirst % 1000LL);
 
 }  // End of String_FirstSeenRaw
 
 static void String_LastSeenRaw(FILE *stream, master_record_t *r) {
-    /* snprintf does write \0, and the max is INCL the terminating \0 */
-    fprintf(stream, "%llu.%03llu", r->msecLast / 1000LL, r->msecLast % 1000LL);
+    fprintf(stream, "%10llu.%03llu", r->msecLast / 1000LL, r->msecLast % 1000LL);
 
 }  // End of String_LastSeenRaw
 
@@ -1411,7 +1440,7 @@ static void String_Flows(FILE *stream, master_record_t *r) {
 
 }  // End of String_Flows
 
-static void String_Tos(FILE *stream, master_record_t *r) { fprintf(stream, "%3u", r->tos); }  // End of String_Tos
+static void String_Tos(FILE *stream, master_record_t *r) { fprintf(stream, "%4u", r->tos); }  // End of String_Tos
 
 static void String_SrcTos(FILE *stream, master_record_t *r) { fprintf(stream, "%4u", r->tos); }  // End of String_SrcTos
 
@@ -1692,22 +1721,26 @@ static void String_pfdir(FILE *stream, master_record_t *r) {
 
 static void String_pfrule(FILE *stream, master_record_t *r) {
     //
-    fprintf(stream, "%4u", r->pfRulenr);
+    fprintf(stream, "%3u", r->pfRulenr);
 }  // End of String_pfrule
 
 #ifdef NSEL
 static void String_nfc(FILE *stream, master_record_t *r) { fprintf(stream, "%10u", r->connID); }  // End of String_nfc
 
 static void String_evt(FILE *stream, master_record_t *r) {
-    if (r->fwXevent) {
-        fprintf(stream, "%7s", FwEventString(r->event));
+    if (printPlain) {
+        fprintf(stream, "%u", r->event);
     } else {
-        fprintf(stream, "%7s", EventString(r->event));
+        if (r->event_flag == FW_EVENT) {
+            fprintf(stream, "%8s", fwEventString(r->event));
+        } else {
+            fprintf(stream, "%8s", natEventString(r->event, SHORTNAME));
+        }
     }
 
 }  // End of String_evt
 
-static void String_xevt(FILE *stream, master_record_t *r) { fprintf(stream, "%7s", EventXString(r->fwXevent)); }  // End of String_xevt
+static void String_xevt(FILE *stream, master_record_t *r) { fprintf(stream, "%7s", fwXEventString(r->fwXevent)); }  // End of String_xevt
 
 static void String_sgt(FILE *stream, master_record_t *r) { fprintf(stream, "%5u", r->sec_group_tag); }  // End of String_sgt
 
