@@ -52,6 +52,7 @@
 #include "nffile.h"
 #include "nfxV3.h"
 #include "output_util.h"
+#include "userio.h"
 #include "util.h"
 
 #define IP_STRING_LEN (INET6_ADDRSTRLEN)
@@ -250,6 +251,8 @@ static void stringsEXflowMisc(FILE *stream, master_record_t *r) {
     char ifOutName[128];
     GetIfName(r->output, ifOutName, sizeof(ifOutName));
 
+    char *DF = r->fragmentFlags & 0x40 ? "DF" : "  ";
+    char *MF = r->fragmentFlags & 0x20 ? "MF" : "  ";
     fprintf(stream,
             "  input        =          %8u%s\n"
             "  output       =          %8u%s\n"
@@ -258,9 +261,10 @@ static void stringsEXflowMisc(FILE *stream, master_record_t *r) {
             "  dst tos      =               %3u\n"
             "  direction    =               %3u\n"
             "  biFlow Dir   =              0x%.2x %s\n"
-            "  end reason   =              0x%.2x %s\n",
+            "  end reason   =              0x%.2x %s\n"
+            "  IPfrag flags =              0x%.2x %s %s\n",
             r->input, ifInName, r->output, ifOutName, r->src_mask, snet, r->src_mask, r->dst_mask, dnet, r->dst_mask, r->dst_tos, r->dir,
-            r->biFlowDir, biFlowString(r->biFlowDir), r->flowEndReason, FlowEndString(r->flowEndReason));
+            r->biFlowDir, biFlowString(r->biFlowDir), r->flowEndReason, FlowEndString(r->flowEndReason), r->fragmentFlags, DF, MF);
 
 }  // End of stringsEXflowMisc
 
@@ -481,8 +485,8 @@ static void stringsEXnselCommon(FILE *stream, master_record_t *r) {
             "  fw event     =             %5u: %s\n"
             "  fw ext event =             %5u: %s\n"
             "  Event time   =     %13llu [%s.%03llu]\n",
-            r->connID, r->event, r->event_flag == FW_EVENT ? FwEventString(r->event) : EventString(r->event), r->fwXevent, EventXString(r->fwXevent),
-            (long long unsigned)r->msecEvent, datestr, (long long unsigned)(r->msecEvent % 1000L));
+            r->connID, r->event, r->event_flag == FW_EVENT ? fwEventString(r->event) : natEventString(r->event, LONGNAME), r->fwXevent,
+            fwXEventString(r->fwXevent), (long long unsigned)r->msecEvent, datestr, (long long unsigned)(r->msecEvent % 1000L));
 
 }  // End of stringsEXnselCommon
 
@@ -542,7 +546,8 @@ static void stringsEXnselUserID(FILE *stream, master_record_t *r) {
 }  // End of stringsEXnselUserID
 
 static void stringsEXnelCommon(FILE *stream, master_record_t *r) {
-    fprintf(stream, "  nat event    =             %5u: %s\n", r->event, r->event_flag == FW_EVENT ? FwEventString(r->event) : EventString(r->event));
+    fprintf(stream, "  nat event    =             %5u: %s\n", r->event,
+            r->event_flag == FW_EVENT ? fwEventString(r->event) : natEventString(r->event, LONGNAME));
 
 }  // End of stringsEXnelCommon
 
