@@ -141,9 +141,11 @@ static void usage(char *name) {
         "-R IP[/port]\tRepeat incoming packets to IP address/port. Max 8 repeaters.\n"
         "-A\t\tEnable source address spoofing for packet repeater -R.\n"
         "-x process\tlaunch process after a new file becomes available\n"
+        "-W workers\toptionally set the number of workers to compress flows\n"
         "-z=lzo\t\tLZO compress flows in output file.\n"
         "-z=bz2\t\tBZIP2 compress flows in output file.\n"
         "-z=lz4[:level]\tLZ4 compress flows in output file.\n"
+        "-z=zstd[:level]\tZSTD compress flows in output file.\n"
         "-B bufflen\tSet socket buffer to bufflen bytes\n"
         "-e\t\tExpire data at each cycle.\n"
         "-D\t\tFork to background\n"
@@ -564,7 +566,7 @@ int main(int argc, char **argv) {
     int family, bufflen, metricInterval;
     time_t twin;
     int sock, do_daemonize, expire, spec_time_extension;
-    int subdir_index, compress, srcSpoofing;
+    int subdir_index, compress, srcSpoofing, workers;
 #ifdef PCAP
     char *pcap_file = NULL;
     char *pcap_device = NULL;
@@ -596,6 +598,7 @@ int main(int argc, char **argv) {
     metricSocket = NULL;
     metricInterval = 60;
     extensionList = NULL;
+    workers = 0;
 
     int c;
     while ((c = getopt(argc, argv, "46AB:b:C:d:DeEf:g:hI:i:jJ:l:m:M:n:p:P:R:S:T:t:u:vVw:x:X:yz::Z")) != EOF) {
@@ -778,6 +781,14 @@ int main(int argc, char **argv) {
                 CheckArgLen(optarg, 128);
                 extensionList = strdup(optarg);
                 break;
+            case 'W':
+                CheckArgLen(optarg, 16);
+                workers = atoi(optarg);
+                if (workers < 0 || workers > MAXWORKERS) {
+                    LogError("Number of working threads out of range 1..%d", MAXWORKERS);
+                    exit(EXIT_FAILURE);
+                }
+                break;
             case 'j':
                 if (compress) {
                     LogError("Use one compression: -z for LZO, -j for BZ2 or -y for LZ4 compression");
@@ -803,7 +814,7 @@ int main(int argc, char **argv) {
                     compress = ParseCompression(optarg);
                 }
                 if (compress == -1) {
-                    LogError("Usage for option -z: set -z=lzo, -z=lz4 or -z=bz2 for valid compression formats");
+                    LogError("Usage for option -z: set -z=lzo, -z=lz4, -z=bz2 or z=zstd for valid compression formats");
                     exit(EXIT_FAILURE);
                 }
                 break;
@@ -884,7 +895,7 @@ int main(int argc, char **argv) {
         exit(EXIT_FAILURE);
     }
 
-    if (!Init_nffile(0, NULL)) exit(254);
+    if (!Init_nffile(workers, NULL)) exit(254);
 
     if (expire && spec_time_extension) {
         LogError("ERROR, -Z timezone extension breaks expire -e");
@@ -928,7 +939,10 @@ int main(int argc, char **argv) {
 
     SetPriv(userid, groupid);
 
-    Init_sflow(verbose, extensionList);
+    if (!Init_sflow(verbose, extensionList)) {
+        LogError("Init_sflow() failed");
+        exit(EXIT_FAILURE);
+    }
 
     if (subdir_index && !InitHierPath(subdir_index)) {
         close(sock);
