@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2009-2023, Peter Haag
+ *  Copyright (c) 2009-2024, Peter Haag
  *  Copyright (c) 2004-2008, SWITCH - Teleinformatikdienste fuer Lehre und Forschung
  *  All rights reserved.
  *
@@ -84,20 +84,67 @@ typedef struct exporter_sflow_s {
 
 } exporter_sflow_t;
 
-static int printRecord = 0;
-static uint32_t recordBaseSize;
-static uint32_t numBaseElements;
+static int PrintRecord = 0;
+
+static int ExtensionsEnabled[MAXEXTENSIONS];
+uint32_t BaseRecordSize = EXgenericFlowSize;
 
 static exporter_sflow_t *GetExporter(FlowSource_t *fs, uint32_t agentSubId, uint32_t meanSkipCount);
 
 #include "inline.c"
 #include "nffile_inline.c"
 
-void Init_sflow(int verbose, char *extensionList) {
-    printRecord = verbose;
-    recordBaseSize = EXgenericFlowSize + EXflowMiscSize + EXasRoutingSize + EXvLanSize + EXmacAddrSize;
-    numBaseElements = 5;
+int Init_sflow(int verbose, char *extensionList) {
+    PrintRecord = verbose;
 
+    if (extensionList) {
+        // Disable all extensions
+        for (int i = 0; i < MAXEXTENSIONS; i++) {
+            ExtensionsEnabled[i] = 0;
+        }
+
+        // get enabled extensions from string
+        int extID = ScanExtension(extensionList);
+        while (extID > 0) {
+            dbg_printf("Enable extension %d\n", extID);
+            ExtensionsEnabled[extID] = 1;
+            extID = ScanExtension(NULL);
+        }
+
+        if (extID == -1) {
+            LogError("Failed to scan extension list.");
+            return 0;
+        }
+
+        // make sure extension 1 is enabled
+        ExtensionsEnabled[1] = 1;
+
+    } else {
+        // Enable all extensions
+        dbg_printf("Enable all extensions\n");
+        for (int i = 0; i < MAXEXTENSIONS; i++) {
+            ExtensionsEnabled[i] = 1;
+        }
+    }
+
+    // extension available in all flows
+    if (ExtensionsEnabled[EXflowMiscID]) {
+        BaseRecordSize += EXflowMiscSize;
+    }
+    if (ExtensionsEnabled[EXvLanID]) {
+        BaseRecordSize += EXvLanSize;
+    }
+    if (ExtensionsEnabled[EXasRoutingID]) {
+        BaseRecordSize += EXasRoutingSize;
+    }
+    if (ExtensionsEnabled[EXmacAddrID]) {
+        BaseRecordSize += EXmacAddrSize;
+    }
+    if (ExtensionsEnabled[EXmplsLabelID]) {
+        BaseRecordSize += EXmplsLabelSize;
+    }
+
+    return 1;
 }  // End of Init_sflow
 
 // called by sfcapd for each packet
@@ -117,7 +164,7 @@ void Process_sflow(void *in_buff, ssize_t in_buff_cnt, FlowSource_t *fs) {
         // TRY
         sample.datap = (uint32_t *)sample.rawSample;
         sample.endp = (u_char *)sample.rawSample + sample.rawSampleLen;
-        readSFlowDatagram(&sample, fs, printRecord);
+        readSFlowDatagram(&sample, fs, PrintRecord);
     } else {
         // CATCH
         dbg_printf("SFLOW: caught exception: %d\n", exceptionVal);
@@ -220,36 +267,51 @@ void StoreSflowRecord(SFSample *sample, FlowSource_t *fs) {
         sample->dcd_dport = 0;
     }
 
-    uint32_t recordSize = recordBaseSize;
-    if (sample->gotIPV6) {
-        recordSize += EXipv6FlowSize;
-    } else {
+    uint32_t recordSize = BaseRecordSize;
+
+    int isV4 = sample->ipsrc.type == SFLADDRESSTYPE_IP_V4;
+    if (isV4 && ExtensionsEnabled[EXipv4FlowID]) {
         recordSize += EXipv4FlowSize;
     }
 
-    if (sample->mpls_num_labels > 0) {
-        recordSize += EXmplsLabelSize;
+    int isV6 = sample->ipsrc.type == SFLADDRESSTYPE_IP_V6;
+    if (isV6 && ExtensionsEnabled[EXipv6FlowID]) {
+        recordSize += EXipv6FlowSize;
     }
+    dbg_printf("IPv4: %u, IPv6: %u\n", isV4, isV6);
 
-    if (sample->nextHop.type == SFLADDRESSTYPE_IP_V4) {
+    if (sample->nextHop.type == SFLADDRESSTYPE_IP_V4 && ExtensionsEnabled[EXipNextHopV4ID]) {
         recordSize += EXipNextHopV4Size;
     }
-    if (sample->nextHop.type == SFLADDRESSTYPE_IP_V6) {
+    if (sample->nextHop.type == SFLADDRESSTYPE_IP_V6 && ExtensionsEnabled[EXipNextHopV6ID]) {
         recordSize += EXipNextHopV6Size;
     }
 
-    if (sample->bgp_nextHop.type == SFLADDRESSTYPE_IP_V4) {
+    if (sample->bgp_nextHop.type == SFLADDRESSTYPE_IP_V4 && ExtensionsEnabled[EXbgpNextHopV4ID]) {
         recordSize += EXbgpNextHopV4Size;
     }
-    if (sample->bgp_nextHop.type == SFLADDRESSTYPE_IP_V6) {
+    if (sample->bgp_nextHop.type == SFLADDRESSTYPE_IP_V6 && ExtensionsEnabled[EXbgpNextHopV6ID]) {
         recordSize += EXbgpNextHopV6Size;
     }
 
-    if (fs->sa_family == AF_INET6) {
-        recordSize += EXipReceivedV6Size;
-    } else {
+    if ((sample->extended_data_tag & SASAMPLE_EXTENDED_DATA_NAT) != 0) {
+        if (sample->nat_src.type == SFLADDRESSTYPE_IP_V4 && ExtensionsEnabled[EXnselXlateIPv4ID]) {
+            recordSize += EXnselXlateIPv4Size;
+        }
+        if (sample->nat_src.type == SFLADDRESSTYPE_IP_V6 && ExtensionsEnabled[EXnselXlateIPv6ID]) {
+            recordSize += EXnselXlateIPv6Size;
+        }
+        if (ExtensionsEnabled[EXnselXlatePortID]) {
+            recordSize += EXnselXlatePortSize;
+        }
+    }
+
+    if (fs->sa_family == AF_INET && ExtensionsEnabled[EXipReceivedV4ID]) {
         recordSize += EXipReceivedV4Size;
     }
+    if (fs->sa_family == AF_INET6 && ExtensionsEnabled[EXipReceivedV6ID]) {
+        recordSize += EXipReceivedV6Size;
+    }
 
     recordSize += sizeof(recordHeaderV3_t);
     if (!CheckBufferSpace(fs->nffile, recordSize)) {
@@ -278,7 +340,13 @@ void StoreSflowRecord(SFSample *sample, FlowSource_t *fs) {
     genericFlow->inBytes = sample->meanSkipCount * sample->sampledPacketSize;
     genericFlow->srcTos = sample->dcd_ipTos;
 
-    if (sample->gotIPV6) {
+    if (isV4 && ExtensionsEnabled[EXipv4FlowID]) {
+        PushExtension(recordHeader, EXipv4Flow, ipv4Flow);
+        ipv4Flow->srcAddr = ntohl(sample->ipsrc.address.ip_v4.addr);
+        ipv4Flow->dstAddr = ntohl(sample->ipdst.address.ip_v4.addr);
+    }
+
+    if (isV6 && ExtensionsEnabled[EXipv6FlowID]) {
         PushExtension(recordHeader, EXipv6Flow, ipv6Flow);
         SetFlag(recordHeader->flags, V3_FLAG_IPV6_ADDR);
 
@@ -293,72 +361,111 @@ void StoreSflowRecord(SFSample *sample, FlowSource_t *fs) {
         ipv6Flow->dstAddr[0] = ntohll(*u);
         u = (uint64_t *)&(b[8]);
         ipv6Flow->dstAddr[1] = ntohll(*u);
-
-    } else {
-        PushExtension(recordHeader, EXipv4Flow, ipv4Flow);
-        ipv4Flow->srcAddr = ntohl(sample->dcd_srcIP.s_addr);
-        ipv4Flow->dstAddr = ntohl(sample->dcd_dstIP.s_addr);
     }
 
-    PushExtension(recordHeader, EXflowMisc, flowMisc);
-    flowMisc->input = sample->inputPort;
-    flowMisc->output = sample->outputPort;
-    flowMisc->srcMask = sample->srcMask;
-    flowMisc->dstMask = sample->dstMask;
+    if (ExtensionsEnabled[EXflowMiscID]) {
+        PushExtension(recordHeader, EXflowMisc, flowMisc);
+        flowMisc->input = sample->inputPort;
+        flowMisc->output = sample->outputPort;
+        flowMisc->srcMask = sample->srcMask;
+        flowMisc->dstMask = sample->dstMask;
+    }
 
-    PushExtension(recordHeader, EXvLan, vLan);
-    vLan->srcVlan = sample->in_vlan;
-    vLan->dstVlan = sample->out_vlan;
+    if (ExtensionsEnabled[EXvLanID]) {
+        PushExtension(recordHeader, EXvLan, vLan);
+        vLan->srcVlan = sample->in_vlan;
+        vLan->dstVlan = sample->out_vlan;
+    }
 
-    PushExtension(recordHeader, EXasRouting, asRouting);
-    asRouting->srcAS = sample->src_as;
-    asRouting->dstAS = sample->dst_as;
+    if (ExtensionsEnabled[EXasRoutingID]) {
+        PushExtension(recordHeader, EXasRouting, asRouting);
+        asRouting->srcAS = sample->src_as;
+        asRouting->dstAS = sample->dst_as;
+    }
 
-    if (sample->nextHop.type == SFLADDRESSTYPE_IP_V4) {
+    if (sample->nextHop.type == SFLADDRESSTYPE_IP_V4 && ExtensionsEnabled[EXipNextHopV4ID]) {
         PushExtension(recordHeader, EXipNextHopV4, ipNextHopV4);
         ipNextHopV4->ip = ntohl(sample->nextHop.address.ip_v4.addr);
     }
-    if (sample->nextHop.type == SFLADDRESSTYPE_IP_V6) {
+    if (sample->nextHop.type == SFLADDRESSTYPE_IP_V6 && ExtensionsEnabled[EXipNextHopV6ID]) {
         uint64_t *addr = (uint64_t *)sample->nextHop.address.ip_v6.addr;
         PushExtension(recordHeader, EXipNextHopV6, ipNextHopV6);
         ipNextHopV6->ip[0] = ntohll(addr[0]);
         ipNextHopV6->ip[1] = ntohll(addr[1]);
     }
 
-    if (sample->bgp_nextHop.type == SFLADDRESSTYPE_IP_V4) {
+    if (sample->bgp_nextHop.type == SFLADDRESSTYPE_IP_V4 && ExtensionsEnabled[EXbgpNextHopV4ID]) {
         PushExtension(recordHeader, EXbgpNextHopV4, bgpNextHopV4);
         bgpNextHopV4->ip = ntohl(sample->bgp_nextHop.address.ip_v4.addr);
     }
-    if (sample->bgp_nextHop.type == SFLADDRESSTYPE_IP_V6) {
+    if (sample->bgp_nextHop.type == SFLADDRESSTYPE_IP_V6 && ExtensionsEnabled[EXbgpNextHopV6ID]) {
         uint64_t *addr = (void *)sample->bgp_nextHop.address.ip_v6.addr;
-        PushExtension(recordHeader, EXipReceivedV6, ipNextHopV6);
-        ipNextHopV6->ip[0] = ntohll(addr[0]);
-        ipNextHopV6->ip[1] = ntohll(addr[1]);
+        PushExtension(recordHeader, EXbgpNextHopV6, bgpNextHopV6);
+        bgpNextHopV6->ip[0] = ntohll(addr[0]);
+        bgpNextHopV6->ip[1] = ntohll(addr[1]);
     }
 
-    PushExtension(recordHeader, EXmacAddr, macAddr);
-    macAddr->inSrcMac = Get_val48((void *)&sample->eth_src);
-    macAddr->outDstMac = Get_val48((void *)&sample->eth_dst);
-    macAddr->inDstMac = 0;
-    macAddr->outSrcMac = 0;
+    if (ExtensionsEnabled[EXmacAddrID]) {
+        PushExtension(recordHeader, EXmacAddr, macAddr);
+        macAddr->inSrcMac = Get_val48((void *)&sample->eth_src);
+        macAddr->outDstMac = Get_val48((void *)&sample->eth_dst);
+        macAddr->inDstMac = 0;
+        macAddr->outSrcMac = 0;
+    }
 
-    if (sample->mpls_num_labels > 0) {
-        PushExtension(recordHeader, EXmplsLabel, mplsLabel);
-        for (int i = 0; i < sample->mpls_num_labels; i++) {
-            mplsLabel->mplsLabel[i] = sample->mpls_label[i];
+    if (ExtensionsEnabled[EXmplsLabelID]) {
+        if (sample->mpls_num_labels > 0) {
+            PushExtension(recordHeader, EXmplsLabel, mplsLabel);
+            for (int i = 0; i < sample->mpls_num_labels; i++) {
+                mplsLabel->mplsLabel[i] = sample->mpls_label[i];
+            }
+        }
+    }
+
+    if ((sample->extended_data_tag & SASAMPLE_EXTENDED_DATA_NAT) != 0) {
+        switch (sample->nat_src.type) {
+            case SFLADDRESSTYPE_IP_V4:
+                if (ExtensionsEnabled[EXnselXlateIPv4ID]) {
+                    dbg_printf("NAT v4 addr\n");
+                    PushExtension(recordHeader, EXnselXlateIPv4, nselXlateIPv4);
+                    nselXlateIPv4->xlateSrcAddr = ntohl(sample->nat_src.address.ip_v4.addr);
+                    nselXlateIPv4->xlateDstAddr = ntohl(sample->nat_dst.address.ip_v4.addr);
+                }
+                break;
+            case SFLADDRESSTYPE_IP_V6: {
+                if (ExtensionsEnabled[EXnselXlateIPv6ID]) {
+                    dbg_printf("NAT v6 addr\n");
+                    PushExtension(recordHeader, EXnselXlateIPv6, nselXlateIPv6);
+                    uint64_t *addr = (void *)sample->nat_src.address.ip_v6.addr;
+                    nselXlateIPv6->xlateSrcAddr[0] = ntohll(addr[0]);
+                    nselXlateIPv6->xlateSrcAddr[1] = ntohll(addr[1]);
+                    addr = (void *)sample->nat_dst.address.ip_v6.addr;
+                    nselXlateIPv6->xlateDstAddr[0] = ntohll(addr[0]);
+                    nselXlateIPv6->xlateDstAddr[1] = ntohll(addr[1]);
+                }
+            } break;
+            default:
+                /* undefined address type - bail out */
+                LogError("SFLOW: getAddress() unknown address type = %d\n", sample->nat_src.type);
+        }
+        if (ExtensionsEnabled[EXnselXlatePortID]) {
+            PushExtension(recordHeader, EXnselXlatePort, nselXlatePort);
+            nselXlatePort->xlateSrcPort = sample->nat_src_port;
+            nselXlatePort->xlateDstPort = sample->nat_dst_port;
         }
     }
 
     // add router IP
-    if (fs->sa_family == PF_INET6) {
+    if (fs->sa_family == PF_INET && ExtensionsEnabled[EXipReceivedV4ID]) {
+        PushExtension(recordHeader, EXipReceivedV4, ipReceivedV4);
+        ipReceivedV4->ip = fs->ip.V4;
+        dbg_printf("Add IPv4 route IP extension\n");
+    }
+    if (fs->sa_family == PF_INET6 && ExtensionsEnabled[EXipReceivedV6ID]) {
         PushExtension(recordHeader, EXipReceivedV6, ipReceivedV6);
         ipReceivedV6->ip[0] = fs->ip.V6[0];
         ipReceivedV6->ip[1] = fs->ip.V6[1];
         dbg_printf("Add IPv6 route IP extension\n");
-    } else {
-        PushExtension(recordHeader, EXipReceivedV4, ipReceivedV4);
-        ipReceivedV4->ip = fs->ip.V4;
-        dbg_printf("Add IPv4 route IP extension\n");
     }
 
     // update first_seen, last_seen
@@ -397,16 +504,26 @@ void StoreSflowRecord(SFSample *sample, FlowSource_t *fs) {
     uint32_t exporterIdent = MetricExpporterID(recordHeader);
     UpdateMetric(fs->nffile->ident, exporterIdent, genericFlow);
 
-    if (printRecord) {
+    if (PrintRecord) {
         flow_record_short(stdout, recordHeader);
     }
-
+#ifdef DEVEL
+    printf("OffsetToPayload %d\n", sample->offsetToPayload);
+    void *p = (void *)sample->header + sample->offsetToPayload;
+    ssize_t len = sample->headerLen - sample->offsetToPayload;
+    dbg_printf("Payload length: %zd\n", len);
+    if (len > 0) {
+        dbg_printf("Payload length: %zd\n", len);
+        DumpHex(stdout, p, len);
+    }
+#endif
     // update file record size ( -> output buffer size )
     fs->nffile->block_header->NumRecords++;
     fs->nffile->block_header->size += recordHeader->size;
 
-    dbg_assert(recordHeader->size == recordSize);
+    dbg_printf("Record size: Header: %u, calc: %u\n", recordHeader->size, recordSize);
+    dbg_assert(recordHeader->size <= recordSize);
 
-    fs->nffile->buff_ptr += recordSize;
+    fs->nffile->buff_ptr += recordHeader->size;
 
 }  // End of StoreSflowRecord
